@@ -1,19 +1,39 @@
 from fastapi import FastAPI
 from pymongo import MongoClient
 from pymongo.database import Database
-from typing import Any, TypeVar
+from typing import Any, TypeVar, Generic
 from pydantic import BaseModel
 
 from settings import BaseServiceSettings, MongoSettings
 
 
 class WithMongo(BaseModel):
+    """
+    The attributes that get added on for the Mongo Mixin
+    """
     mongo: MongoClient
     database: Database
 
 
-class TestableApp(FastAPI):
-    def __init__(self, settings: BaseServiceSettings, **extra: Any):
+_SettingsType = TypeVar("_SettingsType", bound=BaseServiceSettings)
+
+
+class TestableApp(Generic[_SettingsType], FastAPI):
+    """
+    A starter generic app for all Testable microservices.
+    """
+    def __init__(self, settings: _SettingsType, **extra: Any):
+        """
+        Initializes a new FastAPI app with some Pydantic settings.
+
+        Parameters
+        ----------
+        settings : _SettingsType
+            Any `BaseServiceSettings` type settings to initialize app with
+
+        extra : Any
+            Additional kwargs will be passed to FastAPI
+        """
         super().__init__(**extra)
         self.settings = settings
 
